/**
 * @file
 * Center map by Node.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Center map by Node.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches common map style functionality to relevant elements.
   */
  Drupal.behaviors.geolocationCenterNode = {
    attach: function (context, drupalSettings) {

      Drupal.geolocation.executeFeatureOnAllMaps(
        'leaflet_center_node',

        /**
         * @param {GeolocationLeafletMap} map - Current map.
         * @param {MarkerIconSettings} featureSettings - Settings for current feature.
         */
        function (map, featureSettings) {
          var path = window.location.pathname;

          $.each(map.mapMarkers, function (index, marker) {
            if (marker.locationWrapper.data('nid') == path) {

              map.setCenterByCoordinates(marker.getLatLng() );

              if (featureSettings.min_zoom != '') {
                map.setZoom(featureSettings.min_zoom);
              }

            }
          });

          return false;
        },
        drupalSettings
      );
    },
    detach: function (context, drupalSettings) {}
  };
})(jQuery, Drupal);
